set BLUMEN;  # Menge der Blumen
set AUFWAND; # Menge der verschiedenen Aufwaendungen fuer die Blumen

param maxFlaeche >=0; # maximale Flaeche
param kap{AUFWAND} >=0; # maximale Kapazitaet fuer jeden Aufwand
param verbrauch{BLUMEN,AUFWAND} >=0; # Verbrauch jeder Blumen an den einzelnen Aufwand
param db{BLUMEN} >=0; # Deckungsbeitrag
param kosten >= 0; # fixe Kosten fuer die Erntemachine 
param flaecheDahlien >=0; # minimale Flaeche fuer Dahlien
param mengenbonus >=0;  # Mengenvorteil
param grenzflaeche >=0;  # minimal Flaeche fuer Mengenvorteil 

var xflaeche{j in BLUMEN} >=0; # Flaeche fuer jede Blume
var xdahlien binary;   # 0, es werden keine Dahlien gepflanzt, sonst 1
var xgrflaeche{j in BLUMEN} binary; # 0, Blume wird auf weniger als grenzflaeche gepflanzt, sonst 1

# Zielfunktion: maximiere Deckungsbeitrag: Deckungsbeitrag fuer Flaeche +  Mengenbonus - fixen Kosten
maximize Deckungsbeitrag: sum{j in BLUMEN} (db[j]*xflaeche[j] + mengenbonus*xgrflaeche[j]) - xdahlien*kosten ;

# maximale Flaeche
s.t. Flaeche: sum {j in BLUMEN} xflaeche[j] <= maxFlaeche;

# maximale Aufwandskapazitaet
s.t. Kapazitaet {i in AUFWAND}: sum{j in BLUMEN} verbrauch[j,i]*xflaeche[j] <=kap[i];

# Lower und Upper Bound fuer Dahlien
s.t. DahlienLB: xflaeche['DA'] >= flaecheDahlien*xdahlien;
s.t. DahlienUB: xflaeche['DA'] <= maxFlaeche*xdahlien;

# Mengenvorteil, wenn eine Blume auf mehr als grenzflaeche gepflanzt wird
s.t. EconomiesOfScales {j in BLUMEN}: xflaeche[j] >= grenzflaeche*xgrflaeche[j];
